# Mobiliteit.lu API Package

This is a very small package allowing you to access the HAFAS API endpoint to access the realtime data for all Luxembourgish busses, trains and trams which Mobiliteit.lu provides to the public. <br>
All you need is an API key. <br>
For more details about the API or on how to get a key, check out the API documentation on github: https://github.com/Felix3qH4/Mobiliteit.lu-API-documentation